==> trade-center-api-2.3.95-20211201.102234-1-sources.jar: cn/com/duiba/order/center/api/remoteservice/RemoteConsumerExchangeRecordService.java <==
package cn.com.duiba.order.center.api.remoteservice;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.order.center.api.dto.ConsumerExchangeRecordDto;
import cn.com.duiba.order.center.api.paramquery.ConsumerExchangeRecord4PptvQuery;
import cn.com.duiba.wolf.dubbo.DubboResult;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * Created by yansen on 16/9/30.
 */
@AdvancedFeignClient
public interface RemoteConsumerExchangeRecordService {
    
	/**
	 * 插入兑换记录
	 * @param consumerExchangeRecordDto
	 * @return
     */
	DubboResult<ConsumerExchangeRecordDto> insert(ConsumerExchangeRecordDto consumerExchangeRecordDto);
	
	/**
	 * 根据多个参数条件，获取一条兑换记录
	 * map中包含参数可以为id、consumerId、type、relationId、switchs、overDue、json
	 * 其中consumerId是必传参数，否则直接返回null
	 * @param map
	 * @return
     */
	DubboResult<ConsumerExchangeRecordDto> selectOneByMapCondition(Map<String,Object> map);
	
	/**
	 * 根据多个参数条件，获取兑换记录--无分页
	 * map中包含参数可以为consumerId、type、relationId、switchs、overDue、json
	 * 其中consumerId是必传参数，否则直接返回null
	 * @param map
	 * @return
     */
	DubboResult<List<ConsumerExchangeRecordDto>> selectListByMapCondition(Map<String,Object> map);
	
	/**
	 * 根据多个参数条件，获取兑换记录--有分页
	 * map中包含参数可以为consumerId、type、relationId、switchs、overDue、json、start、pageSize
	 * 其中consumerId是必传参数，否则直接返回null
	 * @param map
	 * @return
     */
	DubboResult<List<ConsumerExchangeRecordDto>> selectPageListByMapCondition(Map<String,Object> map);
	
	/**
	 * 分页查询不包含福袋没有过期的兑换记录
	 * @param consumerId
	 * @param start
	 * @param pageSize
	 * @return
	 */
	DubboResult<List<ConsumerExchangeRecordDto>> selectValidWithoutFD(Long consumerId, int start, int pageSize);
	
	/**
	 * 分页查询不包含福袋已过期的兑换记录（90天内）
	 * @param consumerId
	 * @param start
	 * @param pageSize
	 * @return
	 */
	DubboResult<List<ConsumerExchangeRecordDto>> selectInvalidWithoutFD(Long consumerId, int start, int pageSize);
	
	/**
	 * 修改兑换记录信息
	 * @param dto
	 * @return
     */
	DubboResult<Boolean> update(ConsumerExchangeRecordDto dto);

	/**
	 *
	 * @param relationId
	 * @param type
	 * @param consumerId
	 * @return
	 */
	public DubboResult<ConsumerExchangeRecordDto> findByRelationIdAndType(Long relationId, Integer type, Long consumerId);

	/**
	 * 更新缓存在数据库中的json字段
	 * @param id
	 * @param json
	 * @param consumerId
     * @return
     */
	public DubboResult<Integer> updateJson(Long id,String json,long consumerId);


	/**
	 * 查询未过期记录 参数consumerId,offset,max
	 * @param map
	 * @return
     */
	public DubboResult<List<ConsumerExchangeRecordDto>> findConsumerExchangeRecordValid(Map<String, Object> map) ;

	/**
	 * 查询待领取记录
	 * @param map
	 * @return
     */
	public DubboResult<List<ConsumerExchangeRecordDto>> findTakePrizeWaitRecord(Long consumerId) ;

		/**
         *查询过期记录 参数consumerId,offset,max
         * @param map
         * @return
         */
	public DubboResult<List<ConsumerExchangeRecordDto>> findConsumerExchangeRecordInvalid(Map<String, Object> map) ;

	/**
	 * @param consumerId
	 * @return
	 */
	public DubboResult<ConsumerExchangeRecordDto> findOneRecordInvalid(long consumerId);

    /**
     * pptv订单查询接口
     * @param param
     * @return
     */
    DubboResult<List<ConsumerExchangeRecordDto>> findConsumerExchangeRecord4Pptv(ConsumerExchangeRecord4PptvQuery param);

	/**
	 * 根据orderid查找兑换记录，注意数据库中一个orderid存在多条兑换记录
	 * @param consumerId
	 * @param orderId
	 * @return
	 */
	ConsumerExchangeRecordDto findByOrderId(Long consumerId, Long orderId);

	/**
	 * 查询用户在一定时间周期内的有无兑换记录
	 * @param consumerId
	 * @param startTime
	 * @param endTime
	 * @return
	 */
	Integer  findConsumerExchangeRecordNumByTime(Long consumerId,Date startTime,Date endTime);

	/**
	 * 获取最新的30条兑换记录--暂米车生活需求，该处只查询缓存
	 * @param
	 * @return
	 */
	public List<String> findExcRecordFromRedis(Long appId);


	/**
	 *  查询多个用户待领取记录
	 * @return
	 */
	public DubboResult<List<ConsumerExchangeRecordDto>> findTakePrizeWaitRecordByConsumerIds(List<Long> consumerIds) ;


	/**
	 * 查询多个用户未过期记录
	 * 参数consumerIds,offset,max
	 * @param map
	 * @return
	 */
	public DubboResult<List<ConsumerExchangeRecordDto>> findConsumerExchangeRecordValidByConsumerIds(Map<String, Object> map) ;

}

==> trade-center-api-2.4.15-20220322.071038-34-sources.jar: cn/com/duiba/order/center/api/remoteservice/RemoteConsumerExchangeRecordService.java <==
package cn.com.duiba.order.center.api.remoteservice;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.order.center.api.dto.ConsumerExchangeRecordDto;
import cn.com.duiba.order.center.api.paramquery.ConsumerExchangeRecord4PptvQuery;
import cn.com.duiba.wolf.dubbo.DubboResult;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * Created by yansen on 16/9/30.
 */
@AdvancedFeignClient
public interface RemoteConsumerExchangeRecordService {
    
	/**
	 * 插入兑换记录
	 * @param consumerExchangeRecordDto
	 * @return
     */
	DubboResult<ConsumerExchangeRecordDto> insert(ConsumerExchangeRecordDto consumerExchangeRecordDto);
	
	/**
	 * 根据多个参数条件，获取一条兑换记录
	 * map中包含参数可以为id、consumerId、type、relationId、switchs、overDue、json
	 * 其中consumerId是必传参数，否则直接返回null
	 * @param map
	 * @return
     */
	DubboResult<ConsumerExchangeRecordDto> selectOneByMapCondition(Map<String,Object> map);
	
	/**
	 * 根据多个参数条件，获取兑换记录--无分页
	 * map中包含参数可以为consumerId、type、relationId、switchs、overDue、json
	 * 其中consumerId是必传参数，否则直接返回null
	 * @param map
	 * @return
     */
	DubboResult<List<ConsumerExchangeRecordDto>> selectListByMapCondition(Map<String,Object> map);
	
	/**
	 * 根据多个参数条件，获取兑换记录--有分页
	 * map中包含参数可以为consumerId、type、relationId、switchs、overDue、json、start、pageSize
	 * 其中consumerId是必传参数，否则直接返回null
	 * @param map
	 * @return
     */
	DubboResult<List<ConsumerExchangeRecordDto>> selectPageListByMapCondition(Map<String,Object> map);
	
	/**
	 * 分页查询不包含福袋没有过期的兑换记录
	 * @param consumerId
	 * @param start
	 * @param pageSize
	 * @return
	 */
	DubboResult<List<ConsumerExchangeRecordDto>> selectValidWithoutFD(Long consumerId, int start, int pageSize);
	
	/**
	 * 分页查询不包含福袋已过期的兑换记录（90天内）
	 * @param consumerId
	 * @param start
	 * @param pageSize
	 * @return
	 */
	DubboResult<List<ConsumerExchangeRecordDto>> selectInvalidWithoutFD(Long consumerId, int start, int pageSize);
	
	/**
	 * 修改兑换记录信息
	 * @param dto
	 * @return
     */
	DubboResult<Boolean> update(ConsumerExchangeRecordDto dto);

	/**
	 *
	 * @param relationId
	 * @param type
	 * @param consumerId
	 * @return
	 */
	public DubboResult<ConsumerExchangeRecordDto> findByRelationIdAndType(Long relationId, Integer type, Long consumerId);

	/**
	 * 更新缓存在数据库中的json字段
	 * @param id
	 * @param json
	 * @param consumerId
     * @return
     */
	public DubboResult<Integer> updateJson(Long id,String json,long consumerId);


	/**
	 * 查询未过期记录 参数consumerId,offset,max
	 * @param map
	 * @return
     */
	public DubboResult<List<ConsumerExchangeRecordDto>> findConsumerExchangeRecordValid(Map<String, Object> map) ;

	/**
	 * 查询待领取记录
	 * @param map
	 * @return
     */
	public DubboResult<List<ConsumerExchangeRecordDto>> findTakePrizeWaitRecord(Long consumerId) ;

		/**
         *查询过期记录 参数consumerId,offset,max
         * @param map
         * @return
         */
	public DubboResult<List<ConsumerExchangeRecordDto>> findConsumerExchangeRecordInvalid(Map<String, Object> map) ;

	/**
	 * @param consumerId
	 * @return
	 */
	public DubboResult<ConsumerExchangeRecordDto> findOneRecordInvalid(long consumerId);

    /**
     * pptv订单查询接口
     * @param param
     * @return
     */
    DubboResult<List<ConsumerExchangeRecordDto>> findConsumerExchangeRecord4Pptv(ConsumerExchangeRecord4PptvQuery param);

	/**
	 * 根据orderid查找兑换记录，注意数据库中一个orderid存在多条兑换记录
	 * @param consumerId
	 * @param orderId
	 * @return
	 */
	ConsumerExchangeRecordDto findByOrderId(Long consumerId, Long orderId);

	/**
	 * 查询用户在一定时间周期内的有无兑换记录
	 * @param consumerId
	 * @param startTime
	 * @param endTime
	 * @return
	 */
	Integer  findConsumerExchangeRecordNumByTime(Long consumerId,Date startTime,Date endTime);

	/**
	 * 获取最新的30条兑换记录--暂米车生活需求，该处只查询缓存
	 * @param
	 * @return
	 */
	public List<String> findExcRecordFromRedis(Long appId);


	/**
	 *  查询多个用户待领取记录
	 * @return
	 */
	public DubboResult<List<ConsumerExchangeRecordDto>> findTakePrizeWaitRecordByConsumerIds(List<Long> consumerIds) ;


	/**
	 * 查询多个用户未过期记录
	 * 参数consumerIds,offset,max
	 * @param map
	 * @return
	 */
	public DubboResult<List<ConsumerExchangeRecordDto>> findConsumerExchangeRecordValidByConsumerIds(Map<String, Object> map) ;


	/**
	 *查询多个用户过期记录 参数consumerId,offset,max
	 * @param map
	 * @return
	 */
	public DubboResult<List<ConsumerExchangeRecordDto>> findConsumerExchangeRecordInvalidByConsumerIds(Map<String, Object> map) ;


}
